import { Injectable } from '@angular/core';
import { Router } from '@angular/router';

import { Effect, Actions, ofType } from '@ngrx/effects';
import { Action } from '@ngrx/store';

import { Observable } from 'rxjs/Observable';
import { of } from 'rxjs/observable/of';

import 'rxjs/add/operator/catch';
import 'rxjs/add/operator/do';
import 'rxjs/add/operator/exhaustMap';
import 'rxjs/add/operator/switchMap';
import 'rxjs/add/operator/map';
import 'rxjs/add/operator/take';

import { RPCClientError } from '@loafer/ng-rpc';
import { Sensor } from '@overflow/commons-typescript/model/sensor';

import {
  ReadAllByDomainID,
  ReadAllByDomainIDFailure,
  ReadAllByDomainIDSuccess,
  Read,
  ReadSuccess,
  ReadFailure,
  Modify,
  ModifySuccess,
  ModifyFailure,
  ActionType
} from './sensor.action';
import { SensorService } from '../../../service/sensor.service';

@Injectable()
export class Effects {

  constructor(
    private actions$: Actions,
    private sensorService: SensorService,
    private router: Router
  ) { }

  @Effect()
  ReadAllByDomainID$: Observable<Action> = this.actions$
    .ofType(ActionType.ReadAllByDomainID)
    .map((action: ReadAllByDomainID) => action.payload)
    .switchMap(payload => this.sensorService.readAllByDomainID(payload.domainID, payload.pageParams))
    .map(page => {
      return new ReadAllByDomainIDSuccess(page);
    })
    .catch((error: RPCClientError) => {
      return of(new ReadAllByDomainIDFailure(error));
    });

  // @Effect()
  // Read$: Observable<Action> = this.actions$
  //   .ofType(ActionType.Read)
  //   .map((action: Read) => action.payload)
  //   .switchMap(payload => this.sensorHostService.read(payload))
  //   .map(sensorHost => {
  //     return new ReadSuccess(sensorHost);
  //   })
  //   .catch((error: RPCClientError) => {
  //     return of(new ReadFailure(error));
  //   });

  //   @Effect()
  //   Modify$: Observable<Action> = this.actions$
  //     .ofType(ActionType.Modify)
  //     .map((action: Modify) => action.payload)
  //     .switchMap(payload => this.sensorService.modify(payload))
  //     .map(sensor => {
  //       return new ModifySuccess(sensor);
  //     })
  //     .catch((error: RPCClientError) => {
  //       return of(new ModifyFailure(error));
  //     });
}
